@@ -10,6 +10,10 @@ pub mod ansible_extra_vars;
 pub use self::ansible_extra_vars::AnsibleExtraVars;
 pub mod ansible_extra_vars_request;
 pub use self::ansible_extra_vars_request::AnsibleExtraVarsRequest;
+pub mod api_config;
+pub use self::api_config::ApiConfig;
+pub mod api_config_request;
+pub use self::api_config_request::ApiConfigRequest;
 pub mod artifact_types_enum;
 pub use self::artifact_types_enum::ArtifactTypesEnum;
 pub mod callback_token_auth_request;
